@@ -6,7 +6,8 @@ from arangodb.api import Client, Database, Collection, Document
 from arangodb.index.api import Index
 from arangodb.index.general import FulltextIndex, CapConstraintIndex
 from arangodb.index.unique import HashIndex, SkiplistIndex, GeoIndex
-from arangodb.orm.fields import CharField, ForeignKeyField, NumberField, DatetimeField, DateField, BooleanField
+from arangodb.orm.fields import CharField, ForeignKeyField, NumberField, DatetimeField, DateField, BooleanField, \
+    UuidField
 from arangodb.orm.models import CollectionModel
 from arangodb.query.advanced import Query, Traveser
 from arangodb.query.utils.document import create_document_from_result_dict
@@ -738,6 +739,25 @@ class CharFieldTestCase(unittest.TestCase):
         self.assertEqual(str1, str2)
 
 
+class UuidFieldTestCase(unittest.TestCase):
+
+    def setUp(self):
+        pass
+
+    def tearDown(self):
+        pass
+
+    def test_state(self):
+
+        uuid = UuidField()
+
+        self.assertEqual(uuid.text, None)
+
+        uuid.on_create()
+
+        self.assertTrue(isinstance(uuid.text, basestring))
+
+
 class NumberFieldTestCase(unittest.TestCase):
 
     def setUp(self):
